# SL Physics - 2

The course code for this page is **SPH4U7**.

## Magnetism

Magnets are objects with north/south dipoles that create a field around them. Although ferromagnetic substances can repel each other, paramagnetic substances are always attracted to a magnetic field. See [HL Chemistry#Physics properties of transition elements](/sch3uz/#physical-properties-of-transition-elements) for more details.

### Magnetic fields

<img src="/resources/images/magnetic-field.png" width=700>(Source: Kognity)</img>

Similar to electric and gravitational fields, magnetic fields (also known as **B-fields**) are drawn by their effect on a north pole. Since magnetic poles always appear in equal magnitude pairs, all magnetic field lines for a magnet must form closed loops from north to south **outside** and south to north **inside** the magnet. Much like electric field lines, magnetic field lines never touch

<img src="/resources/images/more-magnetic-fields.png" width=700>(Source: Kognity)</img>

Atoms in ferromagnetic materials are tiny magnets with **dipoles**. These dipoles act on neighbouring dipoles and can cause the whole object to align — this is known as an **electric domain**.

!!! note
    Nickel, cobalt, or any alloy with nickel, cobalt, or iron can become magnetised this way.

**Unmagnetised** domains have dipoles pointing in random directions that are aligned when exposed to a magnetic field where they become **magnetised** domains. As such, bar magnets are always broken into smaller magnets, each with two poles — a monopole is impossible to create.

### Straight-line electromagnets

Moving electric charges produce magnetic fields. A circle filled with an "x" indicates that the current is moving away from the viewer in the third dimension while a dotted circle indicates it is moving toward the viewer.

These magnetic fields are centred on the conductor, are in a plane perpendicular to the conductor, and have decreasing magnetic field strength over distance.

<img src="/resources/images/straight-line-electromagnet.png" width=700>(Source: Kognity)</img>

The **right-hand rule** for straight-line conductors indicates that when the conductor would be grasped by the right hand, the thumb would point in the direction of current and the fingers pointing in the direction of the magnetic field.

<img src="/resources/images/right-hand-rule.png" width=700>(Source: Kognity)</img>

### Selenoid electromagnets

A **selenoid** is a conductor coil in a tight helix. Current passed through a selenoid will generate a **uniform magnetic field** inside the coil with a pattern identical to that of a bar magnet outside it.

<img src="/resources/images/selenoid-electromagnet.png" width=700>(Source: Kognity)</img>

The right-hand rule can be applied again to a selenoid to identify the direction of the north pole or direction of magnetic field in the coil:

<img src="/resources/images/selenoid-right-hand-rule.png" width=700>(Source: Kognity)</img>

### Properties of moving charges

As only moving electric charges generate magnetic fields, stationary electric charges are **unaffected** by external magnetic fields. Moving charges are affected by Newton's third law of motion — equal and opposite forces are exerted on the charge and the magnet. As such, where $q$ is the charge of the particle and $\vec{v}\times \vec{B}$ is the **cross product** (vector multiplication) of the velocity of the particle and the magnetic field strength in Teslas:
$$\vec{F_m}=q\vec{v}\times \vec{B}$$

**Magnetic field strength** ($B$) represents the force acting per unit current in a conductor of unit length perpendicular to the field with the unit Tesla ($\pu{T}$)

The **magnetic force** is always plane **perpendicular** to both $\vec{v}$ and $\vec{B}$. Just the magnitude of the force can be found by using the angle between the two vectors ($\theta$):
$$|F_m|=qvB\sin\theta$$

Regardless of $\theta$, the force vector is always perpendicular to both $B$ and $v$,

The above equation can be rearranged to find **electromagnetic** force in terms of current and wire length in a **uniform magnetic field**:
$$|F_em|=BIL\sin\theta$$

<img src="/resources/images/magnet-on-wire.png" width=700>(Source: Kognity</img>

The **right-hand-rule** can be used to determine the direction of force — the thumb points in the direction of current/velocity, the fingers point in the direction of the magnetic field, and the palm points in the direction of force. Alternatively, just three fingers can be used.

<img src="/resources/images/right-hand-rule-forces.png" width=700>(Source: Kognity)</img>

When two straight-line conductors with current flowing through them are brought together, they either mutually attract or repel. The ampere is defined based on the current required to flow through a scenario involving two parallel straight-line conductors.

<img src="/resources/images/parallel-current-conductors.png" width=700>(Source: Kognity)</img>

Inside a **uniform magnetic field**, charges move in **uniform circular motion** at a constant velocity. If the particle did not enter the field at a perfect right angle, some of the velocity is used to change the path of the particle to be in a spiral — still perfectly circular, but additionally moving in the third dimension perpendicular to the circle.
$$\Sigma F_c = F_m$$

## Resources

 - [IB Physics Data Booklet](/resources/g11/ib-physics-data-booklet.pdf)
 - [IB SL Physics Syllabus](/resources/g11/ib-physics-syllabus.pdf)
 - [Dealing with Uncertainties](/resources/g11/physics-uncertainties.pdf)
 - [External: IB Physics Notes](https://ibphysics.org)
