# HL History - 1

The course code for this page is **CHW3MZ**.

## Command terms

The following terms are regularly used by IB and have specific meanings:

 - **Analyse**: Break down an idea into its essential elements
 - **Compare**: Identify and justify the similarities between ideas
 - **Contrast**: Identify and justify the differences between ideas
 - **Discuss**: Provide a balanced review with a range of justified opinions or conclusions
 - **Evaluate**: Appraise an argument with strengths and limitations
 - **Examine**: Consider an argument or concept, revealing its assumptions and interrelations
 - **To what extent**: Consider the merits and demerits of an idea or argument with justified opinions or conclusions

## Historiography

Historiography is the study of how history is developed and how historians have viewed history. It helps develop the ability to view events from multiple perspectives and reveals how others might view events in multiple perspectives. The **historical method** outlines the process of making history from start to finish:

 - **Questions are asked** about any of the following:
	- major/minor long-/short-term **causes** of an event
	- the **nature** of an event — the purpose of the event, the status of the event
	- the immediate/long-term/short-term **impacts** of an event
	- the **ethics** of an event
	- a hypothetical **counterfactual** version of an event
 - **Data is collected** to help answer the questions
 - **Data is analysed** to identify patterns and trends via statistics, make judgements using OPCVL, and make comparisons of the main message (content) and PERMS (political, economical, religious, military, social)
 - **Arguments are created** with a thesis and critical analyses per argument
 - and the **findings are communicated** via any means, including essays, opinion paragraphs, debates, presentations, music, etc.

### Lenses

There are seven main schools of thought historians usually fall under that attempt to explain why history happens.

 - The **great people** lens states that individually great people create changes — without those individuals history would be drastically altered. This school focuses on their individual motivations, relationships, etc.
 - The **structuralist** lens states that changes in economic structures, technology, ideology, and social norms create history.
 - The **decisionist** lens states that the decisions of people change history.
 - The **Marxist** lens states that class conflict creates history. This school focuses on the exploiter and the exploitee and how their conflicts create history.
 - The **Toynbee** lens states that the response of people to crisis creates history.
 - The **post-modern** lens states that history reflects the time period it was written in and the intent of the author. This school asserts that there is no historical truth and focuses on how history is shaped and manipulated to serve the agendas and needs of various civilisations.
 - The **social history** lens states that history should reflect the experience of everyone equally. This school particularly focuses on the treatment of and lives of those often overlooked in historical accounts, such as women and visible minorities.

### Data collection

The abundance of **diverse** data allows for greater perspectives to be gleaned and thus more solutions to a problem. Data and their sources can fall under one of three categories:

 - **Primary** data is from an original source with no sources under it — e.g., newspapers, memoirs, photographs, diaries, etc.
 - **Secondary** data is an interpretation of a primary source(s) with its own argument — e.g., articles, thesises, documentaries, etc.
 - **Tertiary** data compiles secondary sources and should only be used for context — e.g., wikis, textbooks, encyclopedias, etc.

### Logic

!!! definition
    - **Logic** is the study of rules of inference and the analysis of arguments.
    - A **conclusion** is a proposition that follows all others.
    - An **inference** is a connection that acts as a logical leap between a premise and a conclusion.
    - **Logically consistent** statements follow the three laws of thought and do not contradict.
    - **Logically contradicting** statements do not follow the three laws of thought.
    - The **validity** of a statement is its correctness of reasoning via the laws of thought.
    - A **sound** argument is of valid form and has a true premise.
    - An **argument** is a simple statement or disagreement that attempts to reach a conclusion by proving something true with evidence. Good arguments are sound, valid, clear, and avoids hasty conclusions.

**Aristotle** laid the foundations for the principles of formal logic via the three laws of thought.

 - **Law of identity**: everything is identical with itself.
 - **Law of noncontradiction**: contradictory statements cannot both be true.
 - **Law of excluded middle**: any proposition must either be true or false.

!!! example
    - Identity: A football is a football.
    - Noncontradiction: If water and oil do not mix, and substance A mixes in water, it must not be oil.
    - Excluded middle: The Nintendo Switch must either be or not be a potato.

**Deductive** arguments connect a general statement to a more specific statement based on laws, rules, and/or widely accepted principles.

!!! example
    As monkeys like bananas and Lucy is a monkey, Lucy must like bananas.

**Inductive** arguments connect a specific statement to a more general statement based on **empiric** data.

!!! example
    As three of the eight billion humans on Earth are mortal, all humans must be mortal.

### Logical fallacies

 - An **ad hominem** argument attacks the arguer or anything else instead of the argument.
    - e.g., *"You're a Nintendo fanboy; of course you think that."*
 - Arguments that **appeal to authority** use the opinion of an authority on a topic is used as evidence to support an argument.
    - e.g., *"The President of the United States said that we should inject disinfectant into ourselves, so it must be a good idea!"*
 - Arguments that **appeal to emotion** manipulate the recipient's emotions typically via loaded language to win an argument.
    - e.g., *"Those island devils have robbed us of our sleep at night — they must be eradicated!"*
 - Arguments that **appeal to force** use threats to win an argument.
    - e.g., *"I'm right, aren't I?" said the jock, flexing her biceps threateningly.*
 - Arguments that **appeal to ignorance** assert a proposition is true because it has not been proven false.
    - e.g., *"My laptop must secretly have chips in it that no one can detect from aliens because we don't know if there* aren't *undetectable chips in there."*
 - **Bandwagoning or herding** arguments assert that a conclusion is true because it is accepted by most people. This is a result of confirmation bias.
    - e.g., *"Ma, everyone else is jumping off that bridge, so why shouldn't I?"*
 - A fallacy of **accident** wrongly applies a general rule to a specific exception.
    - e.g., *Since surgeons cut people with knives and cutting people with knives is a crime, surgeons are criminals.*
 - An argument that **begs the question** has circular reasoning by having premises that assume its conclusion.
    - e.g., *Acid must be able to eat through your skin because it is corrosive.*
 - **Cherry picking** occurs evidence that supports the conclusion is pointed out while those that contradict the conclusion are ignored or withheld.
    - e.g., *"Look at these perfect cherries — their tree must be in perfect condition!"*
 - A fallacy of **converse accident** wrongly applies a specific exception to a general rule.
    - e.g., *As the Nintendo Switch, a game console, is portable, all game consoles must be portable.*
 - A **complex question** embeds a proposition that is accepted when a direct answer is given to the question. It is also known as a trick question.
    - e.g., *Have you stopped abusing children yet?*
 - Arguments with a **false cause** incorrectly assume a cause to an effect.
    - e.g., imagining correlation implies causation.
 - **Hasty generalisations** appear in inductive generalisations based on insufficient evidence.
    - e.g., *Since the first seven odd numbers are prime or square, all odd numbers must be prime or square.*
 - Arguments that **miss the point** provide an irrelevant conclusion that fails to address the issue of the question.
    - e.g., *"Is it allowed?" "It should be allowed because it's nowhere near as bad as alcohol."*
 - A **non sequitur** is an invalid argument that does not follow the laws of thought.
    - e.g., *All humans are mammals. Whales are mammals. Therefore, whales are humans.*
 - A **no true Scotsman** (appeal to purity) fallacy takes a generalisation and doubles down to protect it by excluding counterexamples typically via emotionally charged language.
    - e.g., *"Although your father is a Scotsman and dances, no* true *Scotsman would dance."*
 - Arguments with **recency bias** put greater importance on recent data over historic data.
    - e.g., *As GameStop's stock has risen over the past few days dramatically, it will continue to do so.*
 - **Red herrings** change the issue of subject away from the original question.
    - e.g., *You should support the new housing bill. We can't continue to see people living in the streets; we must have cheaper housing.*
 - A **straw man** argument misrepresents the opposing position by making their arguments sound more extreme.
    - e.g., *"We should relax laws on immigration." "The instant we let millions of people through our border is when our country falls."*

## Resources

 - [IB History Syllabus](/resources/g11/ib-history-syllabus.pdf)
 - [Textbook: Origins and Development of Authoritarian and Single-Party States](/resources/g11/textbook-authoritarian-states.pdf)
 - [Textbook: Causes and Effects of 20th-Century Wars](/resources/g11/textbook-cause-20-century-wars.pdf)
 - [Textbook: The Move to Global War](/resources/g11/textbook-move-global-war.pdf)
